<?php

/**
 * Input with a check for a valid net mask (range from 1 to 32)
 */
class NetmaskInputTpl extends InputTpl{

    function NetmaskInputTpl($name) {
        $this->InputTpl($name, '/^([1-9]|[1-2][0-9]|3[0-2])$/');
    }

}

/*
 * 
 */

class VlanTag extends InputTpl{
	function VlanTag($name){
		$this->InputTpl($name, '/^([1-9]|[1-9][0-9]|[1-9][0-9]{2}|[1-3][0-9]{3}|40[0-8][0-9]|409[0-4])$/');
	}
}

/* Ip functions */

/**
 * Return True if an IP is in a network
 *
 * If $acceptBoundaries is True, the base network address and the broadcast address are accepted
 */
function ipInNetwork($ip, $network, $mask, $acceptBoundaries = False) {
    $ip = ip2long($ip);
    $network = ip2long($network);
    $mask = intval($mask);
    if (!$acceptBoundaries) {
        if ($ip == $network) return False; /* Network address */
        $ipmask = ip2long("255.255.255.255") << (32 - $mask);
        if ($ip == ($network | (~$ipmask))) return False; /* Broadcast address */
    }
    $ret = True;
    for ($i = 0 ; $i < $mask ; $i++) {
        $n = pow(2, 31 - $i) ;
        if (($n & $ip) != ($n & $network)) {
            $ret = False;
            break;
        }
    }
    return $ret;
}

/**
 * Return True if IP A is lower than IP B
 */
function ipLowerThan($ipa, $ipb) {
    return ip2long($ipa) < ip2long($ipb);
}

/**
 * Return True if IP is into a IP range
 */
function ipInRange($ip, $ipa, $ipb) {
    return (ip2long($ipa) <= ip2long($ip)) and (ip2long($ip) <= ip2long($ipb));
}

/* Some common used utility functions */

function getSubnetOptions($subnet) {
    $options = array();
    if (isset($subnet[0][1]["dhcpOption"])) {
        foreach($subnet[0][1]["dhcpOption"] as $option) {
            list($name, $value) = explode(" ", $option, 2);
            $options[$name] = trim($value, '"');
        }
    }
    if (isset($options["domain-name"])) {
        $tmp = explode(" ", $options["domain-name"]);
        $options["primarydomainname"] = $tmp[0];
    }
    return $options;
}

function getSubnetStatements($subnet) {
    $statements = array();
    if (isset($subnet[0][1]["dhcpStatements"])) {
        foreach($subnet[0][1]["dhcpStatements"] as $statement) {
            list($name, $value) = explode(" ", $statement, 2);
            $statements[$name] = trim($value, '"');
        }
    }
    return $statements;
}

?>
